
#ifndef _UTILITIES_H
#define _UTILITIES_H

#define when(A, B)  if (A) {B}
#define unless(A, B)  if (!(A)) {B}

#define MSG_MAX_VERBOSE 3
#define MSG_ALLWAYS -1
#define mem_malloc_safe(d) (mem_malloc_or_die(d , __FILE__, __LINE__))

typedef struct MSG_REPORT {
  FILE *file;
  char *filename;
  struct MSG_REPORT *next;
} msg_report;

/* Memory management routines */
void * mem_malloc_or_die(size_t size, char *routine, int line);
void mem_malloc_failed_message(const char *routine, const int line);

/* Routines related to string/character manipulation */
char *str_substring(char *sub, char *string, int begin, int end);
int   str_position(char *string, char character);
int   str_positionr(char *string, char character);
char *str_remove_char(char *_new_, char *old, char c);
char *str_remove_digits(char *_new_, char *old);
char *str_upcase(char *_new_, char *old);
char *str_downcase(char *_new_, char *old);

/* Messaging system */
int  msg_set_verbose(int verbose);
int  msg_initialize();
void msg_fprintf(const char *fmt, ...);
int  msg_add_file(const char *filename, const char *mode);
int  msg_remove_file(const char *filename);
void msg_close();
void msg_fclose(FILE *file, const char *filename);
int  msg_message(int verb, const char *fmt, ...);
int  msg_error(const char *fmt, ...);
void msg_exit(int status, const char *fmt, ...);

/* Time & Date stuff */

/* REMEMBER START COUNTING AT 0 */

enum days_of_week {FRIDAY, SATURDAY, SUNDAY, MONDAY, TUESDAY, WEDNESDAY, THURSDAY};

enum months {JANUARY, FEBRUARY, MARCH, APRIL, MAY, JUNE, JULY, 
	     AUGUST, SEPTEMBER, OCTOBER, NOVEMBER, DECEMBER};

enum dateroll{PREC, FOLL, MODPREC, MODFOLL};
  /* mod:  PREC   : If the coupon date falls in a weekend take the
                    last available businessday. 
           FOLL   : If the coupon date falls in a weekend take the
                    next available businessday
           MODPREC: If the coupon date falls in a weekend take the
                    last available businessday. However if the coupon
		    date is in another month the next available business
		    day is taken.
           MODFOLL: If the coupon date falls in a weekend take the
                    next available businessday. However if the coupon
		    date is in another month the next available business
		    day is taken.                            */



typedef struct DATE {
  int n;              /* # of days since ?? */
  int day;
  int mon;
  int yea;
  int dow;
  int sec;
  int min;
  int hou;
  int dst;
  int leap;
  int bus;
} date;

char *time_get_ut_string(char *stime);
int time_isleap(int year);
int time_isbusinessday(date *date);
void time_setdate(date *date, int mon, int day, int yea);
void time_printdate(date *date);
int time_getndays(date *date);
int time_dow(date *date);
void time_printdow(date *date);
int time_getdatefromn(date *date);
int time_daysperyear(int yea);
int time_daysuntilm(int mon, int yea);
int time_daysinm(int mon, int yea);
date *time_adddays(date *date, int n);
date *time_addweeks(date *date, int n);
date *time_addmonths(date *date, int n);
date *time_addbusinessdays(date *date, int n);

#endif    /* end of _UTILITIES_H */
