/** \file DataEntryPanel.h
    \brief Declaration of DataEntryPanel class.
    \author James Peachey

    The Profit software package was developed by Dr. Randall Smith and
    Mr. James Peachey at the High Energy Astrophysics Science Archive
    Research Center (HEASARC) at the Goddard Space Flight Center (GSFC)
    of the National Aeronautics and Space Administration (NASA).
*/
#ifndef profit_DataEntryPanel_h
#define profit_DataEntryPanel_h

#include <list>
#include <string>

#include "RQ_OBJECT.h"
#include "Rtypes.h"
#include "TGLayout.h"
#include "TQObject.h"

// RootCint is finicky if the header files themselves are not included.
#include "TGButton.h"
#include "TGFrame.h"

namespace profit {

  class DataEntryWidget;

  /** \class DataEntryPanel
      \brief Class encapsulating a widget for data entry.
  */
  class DataEntryPanel {
    public:
      RQ_OBJECT("profit::DataEntryPanel")
      ClassDef(DataEntryPanel, 1)

      DataEntryPanel(const std::string & title, TGFrame * parent, UInt_t w = 200, UInt_t h = 100);

      virtual ~DataEntryPanel();

      virtual DataEntryWidget * addWidget(const std::string & label, const std::string & style = "text entry");

      virtual void run();

      virtual void handleOK();

      virtual void handleCancel();

      virtual void handleCloseWindow();

      virtual bool accept();

    protected:
      virtual void buildGui();

    private:
      std::list<DataEntryWidget *> m_widget;
      TGLayoutHints m_hints_expand;
      TGLayoutHints m_hints_centerX;
      std::string m_title;
      TGFrame * m_parent;
      TGTransientFrame * m_transient_frame;
      TGVerticalFrame * m_widget_area;
      TGHorizontalFrame * m_horizontal_frame;
      TGButton * m_ok;
      TGButton * m_cancel;
      UInt_t m_width;
      UInt_t m_height;
      bool m_accept;
  };

}

#endif
