/** \file GuiOStream.h
    \brief Declaration for GuiOStream class.
    \author James Peachey

    The Profit software package was developed by Dr. Randall Smith and
    Mr. James Peachey at the High Energy Astrophysics Science Archive
    Research Center (HEASARC) at the Goddard Space Flight Center (GSFC)
    of the National Aeronautics and Space Administration (NASA).
*/
#ifndef profit_GuiOStream_h
#define profit_GuiOStream_h

#include <sstream>

#include "profit/OStream.h"

class TGTextView;

namespace profit {

  /** \class GuiOStream
      \brief Output stream class which sends its output to a Root text display window.
  */
  class GuiOStream : public OStream {
    public:
      /** \brief Create an GuiOStream with the given client maximum chatter.
          \param text_view The Root widget used to display messages.
      */
      GuiOStream(TGTextView * text_view);

    protected:
      virtual void postProcess();

    private:
      std::ostringstream m_os;
      TGTextView * m_text_view;
  };

}

#endif
