/** \file PlasmaDb.h
    \brief Declaration of PlasmaDb class.
    \author James Peachey

    The Profit software package was developed by Dr. Randall Smith and
    Mr. James Peachey at the High Energy Astrophysics Science Archive
    Research Center (HEASARC) at the Goddard Space Flight Center (GSFC)
    of the National Aeronautics and Space Administration (NASA).
*/
#ifndef profit_PlasmaDb_h
#define profit_PlasmaDb_h

#include "profit/AtomicLevel.h"
#include "profit/AtomicTransition.h"

namespace profit {

  /** \class PlasmaDb
      \brief Singleton class encapsulating access to the APEC plasma database.
  */
  class PlasmaDb {
    public:
      /// \brief Get access to PlasmaDb singleton.
      static PlasmaDb & instance();
      
      virtual ~PlasmaDb();

      /** \brief Search database and return the specified atomic level object. Throw an exception
          if the level is not found.
          \param Z The atomic number.
          \param rmJ
          \param level The level number.
      */
      AtomicLevel findLevel(int Z, int rmJ, int level);

      /** \brief Search database and return the specified atomic transition object. Throw an exception
          if the transition is not found.
          \param Z The atomic number.
          \param rmJ
          \param lower_level The lower level in the transition.
          \param upper_level The upper level in the transition.
      */
      AtomicTransition findTransition(int Z, int rmJ, int lower_level, int upper_level);

    private:
      class Apec;
      PlasmaDb();
      Apec * m_apec;
      double * m_abund;
  };

}

#endif
