/** \file StripChart.h
    \brief Declaration of StripChart class.
    \author James Peachey

    The Profit software package was developed by Dr. Randall Smith and
    Mr. James Peachey at the High Energy Astrophysics Science Archive
    Research Center (HEASARC) at the Goddard Space Flight Center (GSFC)
    of the National Aeronautics and Space Administration (NASA).
*/
#ifndef profit_StripChart_h
#define profit_StripChart_h

#include <string>
#include <vector>

#include "RQ_OBJECT.h"
#include "Rtypes.h"
#include "TGLayout.h"
#include "TQObject.h"

class TGButton;
class TGTransientFrame;
class TGWindow;
class TRootEmbeddedCanvas;

namespace profit {

  class SpectrumView;

  /** \class StripChart
      \brief Class which displays a transient strip-chart editor.
  */
  class StripChart {
    public:
      RQ_OBJECT("profit::StripChart")
      ClassDef(StripChart, 0)

      typedef std::vector<SpectrumView *> view_cont_type;

      StripChart(const SpectrumView * view, const TGWindow * main, UInt_t w, UInt_t h, unsigned int number_plots);

      StripChart(const view_cont_type & view, const TGWindow * main, UInt_t w, UInt_t h);

      virtual ~StripChart();

      virtual void handlePrint() const;

      virtual void handleCloseWindow();

    protected:
      void trackView(const std::string & context, SpectrumView * view);

      void display(const TGWindow * main, UInt_t w, UInt_t h);

    private:
      view_cont_type m_view_cont;
      TGLayoutHints m_hints_expand;
      TGTransientFrame * m_main_frame;
      TGButton * m_print;
      TRootEmbeddedCanvas * m_canvas;
  };

}

#endif
